#
# spec file for package python-pdfminer.six
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pdfminer.six
Version:        20231228
Release:        1.5
Summary:        PDF parser and analyzer
License:        MIT
URL:            https://github.com/pdfminer/pdfminer.six
Source:         https://github.com/pdfminer/pdfminer.six/archive/%{version}.tar.gz#/pdfminer.six-%{version}.tar.gz
BuildRequires:  %{python_module charset-normalizer >= 2.0.0}
BuildRequires:  %{python_module cryptography >= 36.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools-git-versioning}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-charset-normalizer >= 2.0.0
Requires:       python-cryptography >= 36.0.0
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-pdfminer3k = %{version}
Obsoletes:      python-pdfminer3k < %{version}
BuildArch:      noarch
%python_subpackages

%description
Pdfminer.six is a community maintained fork of the original PDFMiner. It
is a tool for extracting information from PDF documents. It focuses on
getting and analyzing text data. Pdfminer.six extracts the text from a
page directly from the sourcecode of the PDF. It can also be used to get
the exact location, font or color of the text.

%prep
%autosetup -p1 -n pdfminer.six-%{version}
sed -i -e '/^#!\//, 1d' pdfminer/psparser.py
sed -i '1i #!%{_bindir}/python3' tools/dumppdf.py tools/pdf2txt.py
sed -i "s/__VERSION__/%{version}/g" pdfminer/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

mv %{buildroot}%{_bindir}/dumppdf.py %{buildroot}%{_bindir}/dumppdf
mv %{buildroot}%{_bindir}/pdf2txt.py %{buildroot}%{_bindir}/pdf2txt
%python_clone -a %{buildroot}%{_bindir}/pdf2txt
%python_clone -a %{buildroot}%{_bindir}/dumppdf

%check
%pytest

%post
%python_install_alternative pdf2txt
%python_install_alternative dumppdf

%postun
%python_uninstall_alternative pdf2txt
%python_uninstall_alternative dumppdf

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/dumppdf
%python_alternative %{_bindir}/pdf2txt
%{python_sitelib}/pdfminer
%{python_sitelib}/pdfminer.six-*.dist-info

%changelog
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 20231228:
  * Removed Support for Python 3.6 and 3.7
  * Output converter for the hOCR format
  * Font name aliases for Arial, Courier New and Times New Roman
  * Documentation on why special characters can sometimes not be
    extracted
  * Storing Bezier path and dashing style of line in LTCurve
  * Broken CI/CD pipeline by setting upper version limit for
    black, mypy, pip and setuptools
  * `flake8` failures
  * `ValueError` when bmp images with 1 bit channel are decoded
  * `ValueError` when trying to decrypt empty metadata values
  * Sphinx errors during building of documentation
  * `TypeError` when getting default width of font
  * Installing typing-extensions on Python 3.6 and 3.7
  * `TypeError` in cmapdb.py when parsing null characters
  * Color "convenience operators" now (per spec) also set color
    space
  * `ValueError` when extracting images, due to breaking changes
    in Pillow
  * Small typo's and issues in the documentation
  * Ignore non-Unicode cmaps in TrueType fonts
  * Using non-hardcoded version string and setuptools-git-
    versioning to enable installation from source and building on
    Python 3.12
  * Usage of `if __name__ == "__main__"` where it was only
    intended for testing purposes
- drop import-from-non-pythonpath-files.patch (upstream)
* Mon Dec 11 2023 Jonathan Papineau <jonathan@jontech.app>
- Update to 20221105
  - Option to disable boxes flow layout analysis when using pdf2txt
  - Add support for PDF 2.0 (ISO 32000-2) AES-256 encryption
  - Support for Paeth PNG filter compression (predictor value = 4)
  - Type annotations
  - Export type annotations from pypi package per PEP561
  - Support for identity cmap's
  - Add support for PDF page labels
  - Installation of Pillow as an optional extra dependency
  - Exporting images without any specific encoding
  - Output converter for the hOCR format
  - Font name aliases for Arial, Courier New and Times New Roman
  - Documentation on why special characters can sometimes not be extracted
- Remove patch python-pdfminer.six-remove-nose.patch
- Update dependencies
* Fri Aug 25 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Apr 11 2023 pgajdos@suse.com
- python-six is not required
- python-pycryptodome is not required
* Tue Nov  9 2021 Steve Kowalik <steven.kowalik@suse.com>
- Use pytest to run the testsuite.
- Add patch import-from-non-pythonpath-files.patch:
  * Allow the test suite to find modules not shipped as modules.
* Tue Sep  8 2020 pgajdos@suse.com
- version update to 20200726
  - Rename PDFTextExtractionNotAllowedError to PDFTextExtractionNotAllowed to revert breaking change
  - Always try to get CMap, not only for identity encodings
  - Support for painting multiple rectangles at once
  - Validate image object in do_EI is a PDFStream
  - Hiding fallback xref by default from dumppdf.py output
  - Raise a warning instead of an error when extracting text from a non-extractable PDF
  - Switched from pycryptodome to cryptography package for AES decryption
  - Python3 shebang line to script in tools
  - Fix ordering of textlines within a textbox when `boxes_flow=None`
  - Allow boxes_flow LAParam to be passed as None, validate the input, and update documentation
  - Also accept file-like objects in high level functions `extract_text` and `extract_pages`
  - Text no longer comes in reverse order when advanced layout analysis is disabled
  - Updated misleading documentation for `word_margin` and `char_margin`
  - Ignore ValueError when converting font encoding differences
  - Grouping of text lines outside of parent container bounding box
  - Group text lines if they are centered
  - Python3 shebang line to script in tools
  - Fix ordering of textlines within a textbox when `boxes_flow=None`
- do not require nose for testing
- added patches
  fix https://github.com/pdfminer/pdfminer.six/pull/489
  + python-pdfminer.six-remove-nose.patch
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Feb 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version v20200124
- Drop support for python2 (not longer supported by upstream)
- Specfile cleanup
- Run testsuite
* Sun Mar 17 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v20181108
* Thu Oct 26 2017 toddrme2178@gmail.com
- Initial version
